@@ -9,21 +9,6 @@
  *****************************************************************************/
 package org.picocontainer;
 
-import org.picocontainer.injectors.FactoryInjector;
-import org.picocontainer.adapters.InstanceAdapter;
-import org.picocontainer.behaviors.AbstractBehaviorFactory;
-import org.picocontainer.behaviors.AdaptingBehavior;
-import org.picocontainer.behaviors.Cached;
-import org.picocontainer.behaviors.Caching;
-import org.picocontainer.behaviors.HiddenImplementation;
-import org.picocontainer.containers.*;
-import org.picocontainer.injectors.AbstractInjector;
-import org.picocontainer.injectors.AdaptingInjection;
-import org.picocontainer.lifecycle.LifecycleState;
-import static org.picocontainer.lifecycle.LifecycleState.*;
-import org.picocontainer.lifecycle.StartableLifecycleStrategy;
-import org.picocontainer.monitors.NullComponentMonitor;
-
 import java.io.Serializable;
 import java.lang.annotation.Annotation;
 import java.lang.ref.WeakReference;
@@ -39,6 +24,24 @@ import java.util.Map;
 import java.util.Properties;
 import java.util.Set;
 
+import org.picocontainer.adapters.InstanceAdapter;
+import org.picocontainer.behaviors.AbstractBehaviorFactory;
+import org.picocontainer.behaviors.AdaptingBehavior;
+import org.picocontainer.behaviors.Cached;
+import org.picocontainer.behaviors.Caching;
+import org.picocontainer.behaviors.HiddenImplementation;
+import org.picocontainer.containers.AbstractDelegatingMutablePicoContainer;
+import org.picocontainer.containers.AbstractDelegatingPicoContainer;
+import org.picocontainer.containers.EmptyPicoContainer;
+import org.picocontainer.containers.ImmutablePicoContainer;
+import org.picocontainer.injectors.AbstractInjector;
+import org.picocontainer.injectors.AdaptingInjection;
+import org.picocontainer.injectors.FactoryInjector;
+import org.picocontainer.lifecycle.DefaultLifecycleState;
+import org.picocontainer.lifecycle.LifecycleState;
+import org.picocontainer.lifecycle.StartableLifecycleStrategy;
+import org.picocontainer.monitors.NullComponentMonitor;
+
 /**
  * <p/>
  * The Standard {@link PicoContainer}/{@link MutablePicoContainer} implementation.
@@ -69,13 +72,10 @@ import java.util.Set;
  * @author Thomas Heller
  * @author Mauro Talevi
  */
+@SuppressWarnings("serial")
 public class DefaultPicoContainer implements MutablePicoContainer, ComponentMonitorStrategy, Serializable  {
 
-    /**
-	 * Serialization UUID.
-	 */
-	private static final long serialVersionUID = -8987815732600681148L;
-
+    private String name;
 
 	/**
 	 * Component factory instance.
@@ -95,9 +95,9 @@ public class DefaultPicoContainer implements MutablePicoContainer, ComponentMoni
     /**
      * Current state of the container.
      */
-    private LifecycleState lifecycleState = CONSTRUCTED;
-    
-    /** 
+    private LifecycleState lifecycleState = new DefaultLifecycleState();
+
+    /**
      * Keeps track of child containers started status.
      */
     private final Set<WeakReference<PicoContainer>> childrenStarted = new HashSet<WeakReference<PicoContainer>>();
@@ -383,14 +383,8 @@ public class DefaultPicoContainer implements MutablePicoContainer, ComponentMoni
 
     /** {@inheritDoc} **/
     public <T> ComponentAdapter<T> removeComponent(final Object componentKey) {
-        if (lifecycleState == STARTED) {
-            throw new PicoCompositionException("Cannot remove components after the container has started");
-        }
-        
-        if (lifecycleState == DISPOSED) {
-            throw new PicoCompositionException("Cannot remove components after the container has been disposed");        	
-        }
-        
+        lifecycleState.removingComponent();
+
         ComponentAdapter<T> adapter = (ComponentAdapter<T>) getComponentKeyToAdapterCache().remove(componentKey);
         getModifiableComponentAdapterList().remove(adapter);
         getOrderedComponentAdapters().remove(adapter);    	
@@ -462,7 +456,7 @@ public class DefaultPicoContainer implements MutablePicoContainer, ComponentMoni
 
     private void throwIfPropertiesLeft(final Properties tmpProperties) {
         if(tmpProperties.size() > 0) {
-            throw new PicoCompositionException("Unprocessed Characteristics:" + tmpProperties +", refer http://picocontainer.org/unprocessed-properties-help.html");
+            throw new PicoCompositionException("Unprocessed Characteristics:" + tmpProperties +", please refer to http://picocontainer.org/unprocessed-properties-help.html");
         }
     }
 
@@ -503,7 +497,7 @@ public class DefaultPicoContainer implements MutablePicoContainer, ComponentMoni
     }
 
     private <T> T getLocalInstance(final ComponentAdapter<T> typedComponentAdapter) {
-        T componentInstance = typedComponentAdapter.getComponentInstance(this);
+        T componentInstance = typedComponentAdapter.getComponentInstance(this, ComponentAdapter.NOTHING.class);
 
         // This is to ensure all are added. (Indirect dependencies will be added
         // from InstantiatingComponentAdapter).
@@ -577,7 +571,7 @@ public class DefaultPicoContainer implements MutablePicoContainer, ComponentMoni
                         }
                     }
                     intoThreadLocal.set(componentAdapter.getComponentImplementation());
-                    instance = componentAdapter.getComponentInstance(this);
+                    instance = componentAdapter.getComponentInstance(this, ComponentAdapter.NOTHING.class);
                 }
             } catch (AbstractInjector.CyclicDependencyException e) {
                 if (parent != null) {
@@ -631,12 +625,8 @@ public class DefaultPicoContainer implements MutablePicoContainer, ComponentMoni
      * @see #removeChildContainer(PicoContainer)
      */
     public void start() {
-    	
-    	if (!lifecycleState.isStartAllowed()) {
-			throw new IllegalStateException("Cannot start.  Current container state was: " + lifecycleState);    		
-    	}
 
-    	lifecycleState = STARTED;
+        lifecycleState.starting();
 
         startAdapters();
         childrenStarted.clear();
@@ -664,11 +654,10 @@ public class DefaultPicoContainer implements MutablePicoContainer, ComponentMoni
      * @see #removeChildContainer(PicoContainer)
      */
     public void stop() {
-    	if (!lifecycleState.isStopAllowed()) {
-			throw new IllegalStateException("Cannot stop.  Current container state was: " + lifecycleState);    		
-    	}
 
-    	for (PicoContainer child : children) {
+        lifecycleState.stopping();
+
+        for (PicoContainer child : children) {
             if (childStarted(child)) {
                 if (child instanceof Startable) {
                     ((Startable)child).stop();
@@ -676,7 +665,7 @@ public class DefaultPicoContainer implements MutablePicoContainer, ComponentMoni
             }
         }
         stopAdapters();
-        lifecycleState = STOPPED;
+        lifecycleState.stopped();
     }
 
     /**
@@ -718,10 +707,8 @@ public class DefaultPicoContainer implements MutablePicoContainer, ComponentMoni
     	if (lifecycleState.isStarted()) {
     		stop();
     	}
-    	
-    	if (!lifecycleState.isDisposedAllowed()) {
-			throw new IllegalStateException("Cannot dispose.  Current lifecycle state is: " + lifecycleState);    		
-    	}
+
+        lifecycleState.disposing();
 
         for (PicoContainer child : children) {
             if (child instanceof MutablePicoContainer) {
@@ -729,7 +716,12 @@ public class DefaultPicoContainer implements MutablePicoContainer, ComponentMoni
             }
         }
         disposeAdapters();
-        lifecycleState = DISPOSED;
+
+        lifecycleState.disposed();
+    }
+
+    public void setLifecycleState(LifecycleState lifecycleState) {
+        this.lifecycleState = lifecycleState;
     }
 
     public MutablePicoContainer makeChildContainer() {
@@ -774,7 +766,7 @@ public class DefaultPicoContainer implements MutablePicoContainer, ComponentMoni
     	checkCircularChildDependencies(child);
     	if (children.add(child)) {
             // @todo Should only be added if child container has also be started
-            if (lifecycleState == STARTED) {
+            if (lifecycleState.isStarted()) {
                 childrenStarted.add(new WeakReference<PicoContainer>(child));
             }
         }
@@ -815,7 +807,14 @@ public class DefaultPicoContainer implements MutablePicoContainer, ComponentMoni
     }
 
     public void accept(final PicoVisitor visitor) {
-        visitor.visitContainer(this);
+    	
+    	//Pico 3 todo, change accept signatures to allow abort at any point in the traversal.
+        boolean shouldContinue = visitor.visitContainer(this);
+        if (!shouldContinue) {
+        	return;
+        }
+        
+        
         componentFactory.accept(visitor); // will cascade through behaviors
         final List<ComponentAdapter<?>> componentAdapters = new ArrayList<ComponentAdapter<?>>(getComponentAdapters());
         for (ComponentAdapter<?> componentAdapter : componentAdapters) {
@@ -872,7 +871,7 @@ public class DefaultPicoContainer implements MutablePicoContainer, ComponentMoni
                 Behavior<?> behaviorAdapter = (Behavior<?>)adapter;
                 if (behaviorAdapter.componentHasLifecycle()) {
                     // create an instance, it will be added to the ordered CA list
-                    adapter.getComponentInstance(DefaultPicoContainer.this);
+                    adapter.getComponentInstance(DefaultPicoContainer.this, ComponentAdapter.NOTHING.class);
                     addOrderedComponentAdapter(adapter);
                 }
             }
@@ -950,12 +949,17 @@ public class DefaultPicoContainer implements MutablePicoContainer, ComponentMoni
 		return componentAdapters;
 	}
 
+    public void setName(String name) {
+        this.name = name;
+    }
+
+    public String toString() {
+        return String.format("%s:%d<%s", (name != null ? name : super.toString()), this.componentAdapters.size(), (parent != null ? parent.toString() : "|"));
+    }
+
+
     private class AsPropertiesPicoContainer extends AbstractDelegatingMutablePicoContainer {
-        /**
-		 * Serialization UUID.
-		 */
-		private static final long serialVersionUID = -4846748925372564136L;
-		
+
 		private final Properties properties;
 
         public AsPropertiesPicoContainer(final Properties... props) {
