@@ -7,9 +7,10 @@ import org.picocontainer.behaviors.AbstractBehavior;
 
 import java.lang.reflect.Type;
 
+@SuppressWarnings("serial")
 public class Decorated extends AbstractBehavior {
     private final Decorator decorator;
-    private static final long serialVersionUID = 438844637809706077L;
+
 
     public Decorated(ComponentAdapter delegate, Decorator decorator) {
         super(delegate);
