@@ -19,13 +19,21 @@ import java.util.LinkedList;
 import java.util.List;
 import java.util.Set;
 
-import org.picocontainer.*;
+import org.picocontainer.ComponentAdapter;
+import org.picocontainer.ComponentMonitor;
+import org.picocontainer.Injector;
+import org.picocontainer.LifecycleStrategy;
+import org.picocontainer.ObjectReference;
+import org.picocontainer.Parameter;
+import org.picocontainer.PicoCompositionException;
+import org.picocontainer.PicoContainer;
+import org.picocontainer.PicoVisitor;
 import org.picocontainer.adapters.AbstractAdapter;
 import org.picocontainer.parameters.ComponentParameter;
 
 /**
  * This ComponentAdapter will instantiate a new object for each call to
- * {@link org.picocontainer.ComponentAdapter#getComponentInstance(PicoContainer)}.
+ * {@link org.picocontainer.ComponentAdapter#getComponentInstance(PicoContainer, Class)}.
  * That means that when used with a PicoContainer, getComponent will
  * return a new object each time.
  *
@@ -34,6 +42,7 @@ import org.picocontainer.parameters.ComponentParameter;
  * @author J&ouml;rg Schaible
  * @author Mauro Talevi
  */
+@SuppressWarnings("serial")
 public abstract class AbstractInjector<T> extends AbstractAdapter<T> implements LifecycleStrategy, Injector<T> {
     /** The cycle guard for the verification. */
     protected transient ThreadLocalCyclicDependencyGuard verifyingGuard;
@@ -43,7 +52,6 @@ public abstract class AbstractInjector<T> extends AbstractAdapter<T> implements
     /** The strategy used to control the lifecycle */
     protected LifecycleStrategy lifecycleStrategy;
     private final boolean useNames;
-    private static final long serialVersionUID = -3329611066565987256L;
 
     /**
      * Constructs a new ComponentAdapter for the given key and implementation.
@@ -315,11 +323,10 @@ public abstract class AbstractInjector<T> extends AbstractAdapter<T> implements
      * @author Aslak Helles&oslash;y
      * @author Jon Tirs&eacute;n
      */
+    @SuppressWarnings("serial")
     public static final class AmbiguousComponentResolutionException extends PicoCompositionException {
-        /**
-		 *
-		 */
-		private static final long serialVersionUID = 646859644465924465L;
+
+
 		private Class<?> component;
         private final Class<?> ambiguousDependency;
         private final Object[] ambiguousComponentKeys;
@@ -373,10 +380,6 @@ public abstract class AbstractInjector<T> extends AbstractAdapter<T> implements
      */
     public static class UnsatisfiableDependenciesException extends PicoCompositionException {
 
-        /**
-		 * Serialization UUID.
-		 */
-		private static final long serialVersionUID = -8652053427387751791L;
 		
 		private final ComponentAdapter<?> instantiatingComponentAdapter;
         private final Set unsatisfiableDependencies;
@@ -421,10 +424,6 @@ public abstract class AbstractInjector<T> extends AbstractAdapter<T> implements
      * @author Aslak Hellesoy
      */
     public static class NotConcreteRegistrationException extends PicoCompositionException {
-        /**
-		 * Serialization UUID.
-		 */
-		private static final long serialVersionUID = 6310754082738087791L;
 		
 		private final Class<?> componentImplementation;
 
